@@ -18,12 +18,12 @@ use strict;
 use Socket;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 use POE qw(Wheel::ListenAccept Wheel::SocketFactory);
-use POE::Component::IKC::Daemon;
+use POE::Component::IKC::Channel;
 
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(create_ikc_client);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 sub DEBUG { 1 }
 
@@ -40,6 +40,7 @@ sub create_ikc_client
     $parms{ip}||='0.0.0.0';             # INET_ANY
     $parms{port}||=603;                 # POE! (almost :)
     $parms{name}||="Client$$";
+    $parms{subscribe}||=[];
     new POE::Session( __PACKAGE__, [qw(_start error connected)], [\%parms]);
 }
 
@@ -61,6 +62,7 @@ sub _start {
     );
   $heap->{on_connect}=$parms->{on_connect};
   $heap->{name}=$parms->{name};
+  $heap->{subscribe}=$parms->{subscribe};
 }
 
 #----------------------------------------------------
@@ -82,13 +84,15 @@ sub error
 sub connected
 {
     my ($heap, $handle) = @_[HEAP, ARG0];
+    DEBUG && print "Client connected\n"; 
 
-    DEBUG && print "Client connected\n"; # give the connection to a daemon
-    create_ikc_daemon($handle, $heap->{name}, $heap->{on_connect});
+                        # give the connection to a channel
+    create_ikc_channel($handle, $heap->{name}, $heap->{on_connect}, 
+                                $heap->{subscribe});
+    delete @{$heap}{qw(name on_connect subscribe)};
+    
 }
 
-
-
 1;
 __END__
 # Below is the stub of documentation for your module. You better edit it!
@@ -163,3 +167,4 @@ Philip Gwyn, <fil@pied.nu>
 L<POE>, L<POE::Component::IKC::Server>
 
 =cut
+
